@@ -1,14 +1,15 @@
 package OpenInteract::Handler::NewUser;
 
-# $Id: NewUser.pm,v 1.6 2002/01/02 02:43:56 lachoy Exp $
+# $Id: NewUser.pm,v 1.7 2002/04/13 17:25:03 lachoy Exp $
 
 use strict;
 use Email::Valid;
 use Data::Dumper  qw( Dumper );
 use SPOPS::Secure qw( :level :scope );
+use SPOPS::Utility;
 
 @OpenInteract::Handler::NewUser::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::NewUser::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::NewUser::default_method    = 'show';
@@ -75,9 +76,9 @@ sub edit {
     $new_user->{login_name} = $login;
     $new_user->{email}      = $email;
     $new_user->{theme_id}   = $R->CONFIG->{default_objects}{theme};
-    my $password            = $R->user->generate_random_code( 12, 'mixed' );
+    my $password            = SPOPS::Utility->generate_random_code( 12, 'mixed' );
     if ( $R->CONFIG->{login}{crypt_password} ) {
-        $new_user->{password}   = $R->user->crypt_it( $password );
+        $new_user->{password}   = SPOPS::Utility->crypt_it( $password );
     }
     $new_user->{removal_date} = $R->user->now( { time => $R->{time} + REMOVAL_TIME } );
     eval { $new_user->save };
