@@ -1,12 +1,12 @@
 package OpenInteract::Handler::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.8 2002/01/02 02:43:55 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.9 2002/04/13 17:20:31 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::SiteTemplate::ISA     = qw( OpenInteract::Handler::GenericDispatcher  SPOPS::Secure );
-$OpenInteract::Handler::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::SiteTemplate::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SiteTemplate::default_method    = 'listing';
@@ -31,10 +31,10 @@ sub listing {
         $R->throw( { code => 403 } );
         $params->{template_list} = [];
     }
-  
+
     $R->{page}->{title} = 'Listing of Template Items';
-    return $R->template->handler( {}, $params, 
-                                  { db      => 'template_list', 
+    return $R->template->handler( {}, $params,
+                                  { db      => 'template_list',
                                     package => 'base_template' } );
 }
 
@@ -42,8 +42,8 @@ sub listing {
 sub show {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
-    my $params = { main_script  => MAIN_SCRIPT, 
-                   error_msg    => $p->{error_msg}, 
+    my $params = { main_script  => MAIN_SCRIPT,
+                   error_msg    => $p->{error_msg},
                    package_list => $R->CONFIG->{package_list} };
 
     my $template = $p->{template};
@@ -95,9 +95,9 @@ sub show {
     }
     $R->DEBUG && $R->scrib( 1, "Displaying $tmpl_name with template ID $template->{template_id} using shell ($tmpl_name)" );
     $R->{page}->{title} = 'Detail of Template Item';
-    return $R->template->handler( {}, $params, 
-                                  { db      => $tmpl_name, 
-                                    package => 'base_template' } ); 
+    return $R->template->handler( {}, $params,
+                                  { db      => $tmpl_name,
+                                    package => 'base_template' } );
 }
 
 
@@ -137,12 +137,12 @@ sub edit {
         $template->{package} = $alt;   
         $R->DEBUG && $R->scrib( 1, "Set package to alternate typed in by user ($alt)" );
     }
-  
+
     eval { $template->save };
     if ( $@ ) {
         warn "Error saving template ($SPOPS::Error::system_msg); trying again.";
-        $template->{name} = ( $old_name ) 
-                            ? $old_name : $template->generate_random_code( 8 );
+        $template->{name} = $old_name ||
+                            SPOPS::Utility->generate_random_code( 8 );
         eval { $template->save };
         if ( $@ ) {
             $p->{error_msg} = "Error saving template with new name. Please try again.";
@@ -166,7 +166,7 @@ sub remove {
             my $error_msg = 'Cannot remove template: error retrieving template for removal.';
             return $class->listing({ error_msg => $error_msg });
         }
-    
+
         if ( $template->{tmp_security_level} < SEC_LEVEL_WRITE ) {
             my $user_msg = 'Sorry, you do not have access to remove this template object. Returning to listing.';
             return $class->listing({ error_msg => $user_msg });
@@ -182,34 +182,3 @@ sub remove {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-OpenInteract::Handler::SiteTemplate - List, display and edit templates
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 METHODS
-
-=head1 TO DO
-
-=head1 BUGS
-
-=head1 COPYRIGHT
-
-Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHORS
-
-Chris Winters <chris@cwinters.com>
-
-=cut
